-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009, 2010, 2011, 2012, 2013 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Nicolas Casalini "DarkGod"
-- darkgod@te4.org

newTalent{
	name = "Crusade",
	type = {"celestial/combat", 1},
	require = divi_req1,
	random_ego = "attack",
	points = 5,
	cooldown = 8,
	positive = 10,
	tactical = { ATTACK = {LIGHT = 2} },
	range = 1,
	requires_target = true,
	getDamage = function(self, t) return self:combatTalentWeaponDamage(t, 0.8, 1.6) end,
	action = function(self, t)
		local tg = {type="hit", range=self:getTalentRange(t)}
		local x, y, target = self:getTarget(tg)
		if not x or not y or not target then return nil end
		if core.fov.distance(self.x, self.y, x, y) > 1 then return nil end
		self:attackTarget(target, DamageType.LIGHT, t.getDamage(self, t), true)
		self:attackTarget(target, DamageType.LIGHT, t.getDamage(self, t), true)
		return true
	end,
	info = function(self, t)
		local damage = t.getDamage(self, t)
		return ([[Concentrate the power of the Sun into two blows; each blow does %d%% of your weapon damage as light damage.]]):
		format(100 * damage)
	end,
}

newTalent{
	name = "Wave of Power",
	type = {"celestial/combat",2},
	require = divi_req2,
	points = 5,
	random_ego = "attack",
	cooldown = 6,
	positive = 10,
	tactical = { ATTACK = 2 },
	requires_target = true,
	range = function(self, t) return 2 + self:getStr(8) end,
	getDamage = function(self, t) return self:combatTalentWeaponDamage(t, 1.1, 1.9) end,
	action = function(self, t)
		local tg = {type="bolt", range=self:getTalentRange(t), talent=t}
		local x, y = self:getTarget(tg)
		if not x or not y then return nil end
		local _ _, x, y = self:canProject(tg, x, y)
		local target = game.level.map(x, y, Map.ACTOR)
		if target then
			self:attackTarget(target, nil, t.getDamage(self, t), true)
		else
			return
		end
		return true
	end,
	info = function(self, t)
		local damage = t.getDamage(self, t)
		return ([[In a pure display of power, you project a melee attack, doing %d%% damage.
		The range will increase with your Strength.]]):
		format(100 * damage)
	end,
}

newTalent{
	name = "Body of Light",
	type = {"celestial/combat", 3},
	mode = "sustained",
	require = divi_req3,
	points = 5,
	cooldown = 15,
	sustain_positive = 15,
	tactical = { BUFF = 2 },
	getCombatHaste = function(self, t) return self:getTalentLevel(t) * 0.025 end,
	getMovementHaste = function(self, t) return self:getTalentLevel(t) * 0.04 end,
	activate = function(self, t)
		game:playSoundNear(self, "talents/spell_generic2")
		local CombatHaste = t.getCombatHaste(self, t)
		local MovementHaste = t.getMovementHaste(self, t)
		return {
		comb_speed = self:addTemporaryValue("combat_physspeed", CombatHaste),
		mov_speed = self:addTemporaryValue("movement_speed", MovementHaste)
		}
	end,
	deactivate = function(self, t, p)
		self:removeTemporaryValue("combat_physspeed", p.comb_speed)
		self:removeTemporaryValue("movement_speed", p.mov_speed)
		return true
	end,
	info = function(self, t)
		local CombatHaste = 100*t.getCombatHaste(self, t)
		local MovementHaste = 100*t.getMovementHaste(self, t)
		return ([[Your body is infused with light, increasing your attack speed by %d%% and your movement speed by %d%%]]):
		format(CombatHaste, MovementHaste)
	end,
}

newTalent{
	name = "Weapon of Light",
	type = {"celestial/combat", 4},
	mode = "sustained",
	require = divi_req4,
	points = 5,
	cooldown = 20,
	sustain_positive = 20,
	tactical = { BUFF = 2 },
	range = 10,
	activate = function(self, t)
		game:playSoundNear(self, "talents/spell_generic2")
		local ret = {
		}
		return ret
	end,
	deactivate = function(self, t, p)
		return true
	end,
	info = function(self, t)
		local light_damage = 6 * self:getTalentLevel(t)
		return ([[Infuse your weapon with the power of the Sun, increasing each blow by %d%% as light damage at the cost of 3 positive energy.
		If you do not have enough positive energy, the sustain will have no effect.]]):format(light_damage)
	end,
}
